@@ -1,4 +1,5 @@
 # Token = namedtuple('Token', ['address', 'name', 'code_hash'], defaults=(None,) * 3)
+import os
 import sys
 from dataclasses import dataclass
 
@@ -34,12 +35,12 @@ class Config:
     chain_id: int
     symbol: str
     block_explorer: str
-    bridge: str = "",
-    faucet: str = "",
-    gas: int = 6000000,
+    bridge: str = ""
+    faucet: str = ""
+    gas: int = 6000000
     gasPrice: int = 1059100000
     one: int = 1000000000000000000
-    wait_time: int = 6,
+    wait_time: int = 6
     # Oracle from Chainlink
     # https://docs.chain.link/docs/vrf-contracts/
     link_token: str = None,
@@ -56,6 +57,16 @@ class Key:
     network: str
 
 
+@dataclass
+class MetaSetting:
+    optimization_runs: int
+    optimization_enabled: bool
+    evm: str
+    linkLib: dict
+    solidity_ver_full: str
+    solidity_ver: str
+
+
 class Bolors:
     OK = '\033[92m'  # GREEN
     WARNING = '\033[93m'  # YELLOW
@@ -112,9 +123,17 @@ class Evm:
     """
 
 
+class DefaultKeys:
+    k0 = "000000000000000000000000000000000000000000000000000000000000001e"
+
+
+root_base_path = os.path.join(os.path.dirname(__file__))
+
 __all__ = [
     '__version__',
     'Evm',
     'Config',
-    'Bolors'
+    'Bolors',
+    'DefaultKeys',
+    'root_base_path'
 ]
