@@ -27,6 +27,42 @@ def Ethereum() -> Config:
     )
 
 
+def EthereumFL() -> Config:
+    return Config(
+        network_name="EthereumMainnet",
+        rpc_url="https://rpc.flashbots.net",
+        chain_id=1,
+        symbol="ETH",
+        block_explorer="https://flashbots-explorer.marto.lol/",
+        link_token="0x514910771AF9Ca656af840dff83E8264EcF986CA",
+        link_vrf_coordinator="0xf0d54349aDdcf704F77AE15b96510dEA15cb7952",
+        link_keyhash="0xAA77729D3466CA35AE8D28B3BBAC7CC36A5031EFDC430821C02BC31A238AF445"
+    )
+
+
+def GoerliTestnetFL() -> Config:
+    return Config(
+        network_name="GoerliTestnet",
+        rpc_url="https://rpc-goerli.flashbots.net",
+        chain_id=5,
+        symbol="ETH",
+        block_explorer="https://flashbots-explorer.marto.lol/",
+        link_token="0x514910771AF9Ca656af840dff83E8264EcF986CA",
+        link_vrf_coordinator="0xf0d54349aDdcf704F77AE15b96510dEA15cb7952",
+        link_keyhash="0xAA77729D3466CA35AE8D28B3BBAC7CC36A5031EFDC430821C02BC31A238AF445"
+    )
+
+
+def GoerliTestnet() -> Config:
+    return Config(
+        network_name="GoerliTestnet",
+        rpc_url="https://goerli.infura.io/v3/9aa3d95b3bc440fa88ea12eaa4456161",
+        chain_id=5,
+        symbol="ETH",
+        block_explorer="https://goerli.etherscan.io"
+    )
+
+
 def BSCMain() -> Config:
     return Config(
         network_name="BinanceMainnet",
@@ -43,10 +79,10 @@ def BSCMain() -> Config:
 def PolygonMumbai() -> Config:
     return Config(
         network_name="PolygonMumbaiTestnet",
-        rpc_url="https://bsc-dataseed1.binance.org",
-        chain_id=56,
-        symbol="BNB",
-        block_explorer="https://bscscan.com",
+        rpc_url="https://rpc-mumbai.maticvigil.com",
+        chain_id=80001,
+        symbol="MATIC",
+        block_explorer="https://mumbai.polygonscan.com/",
         link_token="0x326C977E6efc84E512bB9C30f76E30c160eD06FB",
         link_keyhash="0x6e75b569a01ef56d18cab6a8e71e6600d6ce853834d4a5748b720d06f878b3a4",
         link_vrf_coordinator="0x8C7382F9D8f56b33781fE506E897a4F1e2d17255"
@@ -56,19 +92,19 @@ def PolygonMumbai() -> Config:
 def PolygonMainnet() -> Config:
     return Config(
         network_name="PolygonMainnet",
-        rpc_url="https://bsc-dataseed1.binance.org",
-        chain_id=56,
-        symbol="BNB",
-        block_explorer="https://bscscan.com",
+        rpc_url="https://polygon-rpc.com",
+        chain_id=137,
+        symbol="MATIC",
+        block_explorer="https://explorer.matic.network/",
         link_token="0xb0897686c545045aFc77CF20eC7A532E3120E0F1",
         link_keyhash="0xf86195cf7690c55907b2b611ebb7343a6f649bff128701cc542f0569e2c549da",
         link_vrf_coordinator="0x3d2341ADb2D31f1c5530cDC622016af293177AE0"
     )
 
 
-def Kovan() -> Config:
+def KovanTestnet() -> Config:
     return Config(
-        network_name="Kovan",
+        network_name="KovanTestnet",
         rpc_url="https://kovan.infura.io/v3/2019a99711c648f8951a640e8031ca33",
         chain_id=42,
         symbol="KETH",
@@ -79,9 +115,9 @@ def Kovan() -> Config:
     )
 
 
-def Ropsten() -> Config:
+def RopstenTestnet() -> Config:
     return Config(
-        network_name="Ropsten",
+        network_name="RopstenTestnet",
         rpc_url="https://ropsten.infura.io/v3/9aa3d95b3bc440fa88ea12eaa4456161",
         chain_id=3,
         symbol="RETH",
@@ -89,13 +125,13 @@ def Ropsten() -> Config:
     )
 
 
-def GoerliTestnet() -> Config:
+def RinkebyTestnet() -> Config:
     return Config(
-        network_name="Goerli",
-        rpc_url="https://goerli.infura.io/v3/9aa3d95b3bc440fa88ea12eaa4456161",
-        chain_id=5,
+        network_name="RinkebyTestnet",
+        rpc_url="https://rinkeby.infura.io/v3/9aa3d95b3bc440fa88ea12eaa4456161",
+        chain_id=4,
         symbol="ETH",
-        block_explorer="https://goerli.etherscan.io"
+        block_explorer="https://rinkeby.etherscan.io/"
     )
 
 
@@ -168,33 +204,29 @@ def OKChainTestnet() -> Config:
     )
 
 
-"""
-def RSCTestnet() -> Config:
-    return Config(
-        network_name="RSCTestnet",
-        rpc_url="",
-        chain_id=1235,
-        symbol="RSCT",
-        block_explorer="",
-        wait_time=6,
-        one=10 ** 18,
-    )
-"""
-
-
 def RSCMainnet() -> Config:
     return Config(
         network_name="RSCMainnet",
         rpc_url="https://rpc-mainnet.raisc.io",
         chain_id=1023,
         symbol="RSC",
-        block_explorer="http://www.raisc.io/",
+        block_explorer="http://explorer.raisc.io/",
         link_token="0x79e93714E4049Ae8745F1FA21838d6FdfDCa9cA6",
         link_vrf_coordinator="0x3c89bdbfF0B1a27c126b89e78F21a7B66DA2dbeC",
         link_keyhash="0x66c8089c4313b58a4344f69f796705ea1a7b2c180836e56f4785bde84f7af32f"
     )
 
 
+def OasisMainnet() -> Config:
+    return Config(
+        network_name="OasisChain",
+        rpc_url="https://rpc1.oasischain.io",
+        chain_id=1023,
+        symbol="OAC",
+        block_explorer="https://scan.oasischain.io/"
+    )
+
+
 def AvalancheFujiTestnet() -> Config:
     return Config(
         network_name="AvalancheTestnet",
@@ -218,7 +250,7 @@ def AvalancheMainnet() -> Config:
 def OptimisticEthereum() -> Config:
     return Config(
         network_name="OptimisticEthereumMainnet",
-        rpc_url="https://mainnet.optimism.io/",
+        rpc_url="https://mainnet.optimism.io",
         chain_id=10,
         symbol="ETH",
         block_explorer="https://optimistic.etherscan.io/"
@@ -228,7 +260,7 @@ def OptimisticEthereum() -> Config:
 def OptimisticEthereumTestnet() -> Config:
     return Config(
         network_name="OptimisticEthereumMainnet",
-        rpc_url="https://kovan.optimism.io/",
+        rpc_url="https://kovan.optimism.io",
         chain_id=69,
         symbol="ETH",
         block_explorer="https://kovan-optimistic.etherscan.io/"
@@ -239,7 +271,7 @@ def OptimisticEthereumTestnet() -> Config:
 def NearAuroraTestnet() -> Config:
     return Config(
         network_name="AuroraTestnet",
-        rpc_url="https://testnet.aurora.dev/",
+        rpc_url="https://testnet.aurora.dev",
         chain_id=1313161555,
         symbol="NEAR",
         block_explorer="https://explorer.testnet.near.org/"
@@ -249,8 +281,148 @@ def NearAuroraTestnet() -> Config:
 def NearAuroraMainnet() -> Config:
     return Config(
         network_name="AuroraTestnet",
-        rpc_url="https://testnet.aurora.dev/",
+        rpc_url="https://rpc.ankr.com/near",
         chain_id=1313161554,
         symbol="NEAR",
         block_explorer="https://explorer.near.org/"
     )
+
+
+def ArbitrumOne() -> Config:
+    return Config(
+        network_name="ArbitrumOne",
+        rpc_url="https://rpc.ankr.com/arbitrum",
+        chain_id=42161,
+        symbol="ETH",
+        block_explorer="https://arbiscan.io/"
+    )
+
+
+def FantomOperaMainnetRPC() -> Config:
+    return Config(
+        network_name="FantomOpera",
+        rpc_url="https://rpc.ftm.tools",
+        chain_id=250,
+        symbol="FTM",
+        block_explorer="https://ftmscan.com/"
+    )
+
+
+def FantomTestnetRPC() -> Config:
+    return Config(
+        network_name="FantomTestnet",
+        rpc_url="https://rpc.testnet.fantom.network",
+        chain_id=4002,
+        symbol="FTM",
+        block_explorer="https://testnet.ftmscan.com/"
+    )
+
+
+def HarmonyMainnet() -> Config:
+    return Config(
+        network_name="HarmonyMainnet",
+        rpc_url="https://api.harmony.one",
+        chain_id=1666600000,
+        symbol="ONE",
+        block_explorer="https://explorer.harmony.one/"
+    )
+
+
+def HarmonyTestnet() -> Config:
+    return Config(
+        network_name="HarmonyTestnet",
+        rpc_url="https://api.s0.b.hmny.io",
+        chain_id=1666700000,
+        symbol="ONE",
+        block_explorer="https://explorer.harmony.one/"
+    )
+
+
+def Kucoin() -> Config:
+    return Config(
+        network_name="KucoinMainnet",
+        rpc_url="https://rpc-mainnet.kcc.network",
+        chain_id=321,
+        symbol="KCS",
+        block_explorer="https://scan.kcc.network/"
+    )
+
+
+def KucoinTestnet() -> Config:
+    return Config(
+        network_name="KucoinTestnet",
+        rpc_url="https://scan-testnet.kcc.network",
+        chain_id=322,
+        symbol="KCS",
+        block_explorer="https://scan-testnet.kcc.network/"
+    )
+
+
+def Elastos() -> Config:
+    return Config(
+        network_name="Elastos",
+        rpc_url="https://api.elastos.io/eth",
+        chain_id=20,
+        symbol="KCS",
+        block_explorer="https://explorer.elaeth.io/"
+    )
+
+
+def Gnosis() -> Config:
+    return Config(
+        network_name="Gnosis",
+        rpc_url="https://rpc.gnosischain.com",
+        chain_id=100,
+        symbol="XDAI",
+        block_explorer="https://blockscout.com/xdai/mainnet/"
+    )
+
+
+def Ubiq() -> Config:
+    return Config(
+        network_name="Ubiq",
+        rpc_url="https://rpc.octano.dev",
+        chain_id=8,
+        symbol="UBQ",
+        block_explorer="https://ubiqscan.io/"
+    )
+
+
+def Cronos() -> Config:
+    return Config(
+        network_name="Cronos",
+        rpc_url="https://evm-cronos.crypto.org",
+        chain_id=25,
+        symbol="CRO",
+        block_explorer="https://cronos.crypto.org/explorer/"
+    )
+
+
+def Solana() -> Config:
+    return Config(
+        network_name="SOL",
+        rpc_url="https://rpc.ankr.com/solana",
+        chain_id=25221,
+        symbol="CRO",
+        block_explorer="https://solscan.io/"
+    )
+
+
+def SmartBCH() -> Config:
+    return Config(
+        network_name="BCHMainnet",
+        rpc_url="https://smartbch.fountainhead.cash/mainnet",
+        chain_id=10000,
+        symbol="BCH",
+        block_explorer="https://www.smartscan.ca.sh/"
+    )
+
+
+def CeloMainnet() -> Config:
+    return Config(
+        network_name="CeloMainnet",
+        rpc_url="https://rpc.ankr.com/celo",
+        chain_id=42220,
+        symbol="CELO",
+        block_explorer="https://celoscan.com/"
+    )
